@@ -1,6 +1,6 @@
 from stackifyapm.instrumentation.packages.base import AbstractInstrumentedModule
 from stackifyapm.traces import CaptureSpan
-from stackifyapm.utils import get_method_name
+from stackifyapm.utils import compat, get_method_name
 from stackifyapm.utils.helper import is_async_span
 
 
@@ -45,8 +45,10 @@ class PythonMemcachedInstrumentation(AbstractInstrumentedModule):
             "operation": method_name,
         }
         cache_name = args and args[0] or None
-        if cache_name:
-            extra_data['cache_key'] = cache_name
+        if isinstance(cache_name, compat.binary_type):
+            extra_data['cache_key'] = cache_name.decode('utf-8')
+        elif cache_name:
+            extra_data['cache_key'] = str(cache_name)
 
         with CaptureSpan(name, "cache.memcached", extra_data, is_async=is_async_span()):
             return wrapped(*args, **kwargs)
